/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * 
 */

package com.kvisco.xsl;

import org.w3c.dom.*;

/**
 * Represents an AttributeExpr
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class AttributeExpr implements NodeExpr {
    
      //----------------/
     //- Constructors -/
    //----------------/
    
    String name = null;
    
    public AttributeExpr(String name) {
        super();
        this.name = name;
    } //-- AttributeExpr
    
      //------------------/
     //- Public Methods -/
    //------------------/
    
    
    /**
     * Returns the String representation of this NodeExpr
    **/
    public String toString() {
        return name;
    } //-- toString
    
    
    /**
     * Evaluates this Expr using the given context Node and ProcessorState
     * @param context the current context Node
     * @param ps the ProcessorState that contains the current processing 
     * environment
     * @return the ExprResult
    **/
    public ExprResult evaluate(Node context, ProcessorState ps)
        throws InvalidExprException 
    {
        NodeSet nodeSet = new NodeSet();
        
        if ((context == null) || (this.name == null)) return nodeSet;
        if (context.getNodeType() == Node.ELEMENT_NODE) {
            Element element = (Element)context;
            if (Names.WILD_CARD.equals(this.name)) {
                NamedNodeMap atts = element.getAttributes();
                if (atts != null) {
                    for (int i = 0; i < atts.getLength(); i++) {
                        nodeSet.add(atts.item(i));
                    }
                }
            }
            else {
                Attr attr = element.getAttributeNode(this.name);
                if (attr != null) nodeSet.add(attr);
            }
        }
        return nodeSet;
    } //-- evaluate
    
    public short getExprType() { return Expr.BOOLEAN; }
    
    
    public String getName() { return this.name; }
        
    /**
     * Returns the type of this NodeExpr
     * @return the type of this NodeExpr
    **/
    public short getNodeExprType() { return NodeExpr.ATTRIBUTE_EXPR; }
    
    
    /**
     * Determines if the given node is matched by this NodeExpr
     * within the given context
    **/
    public boolean matches(Node node, Node context, ProcessorState ps)
        throws InvalidExprException
    {
        if (node == null) return false;
        String nodeName;
        if (node.getNodeType() == Node.ATTRIBUTE_NODE) {
            Attr attr = (Attr) node;
            nodeName = attr.getName();
            return (Names.WILD_CARD.equals(this.name) ||
                    nodeName.equals(this.name));
        }
        return false;
    } //-- matches
    
} //-- AttributeExpr