/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * 
 */

package com.kvisco.xsl.functions;
import com.kvisco.xsl.*;
import com.kvisco.util.*;
import org.w3c.dom.Node;

/**
 * A class that represents the XSL Boolean(BooleanExpr) function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class BooleanFunctionCall extends FunctionCall {
    
    /**
     * Creates a new BooleanFunctionCall
    **/
    public BooleanFunctionCall() {
        super(Names.BOOLEAN_FN);
    } //-- BooleanFunctionCall
    
    /**
     * Evalutes this FunctionCall using the given Node as
     * the context. This method will always return a BooleanResult
    **/
    public ExprResult evaluate(Node context, ProcessorState ps) 
        throws InvalidExprException
    {
        
        List params = super.getParameterList();
        
        if (params.size() != 1)
            throw new InvalidExprException("invalid number of parameters");
            
        Expr expr = (Expr) params.get(0);
        if (expr != null)  {
            return new BooleanResult(expr.evaluate(context, ps));
        }
        return BooleanResult.FALSE_RESULT;
    } //-- evaluate
    
} //-- BooleanFunctionCall