/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 */

package com.kvisco.xsl.functions;
import com.kvisco.xsl.*;
import com.kvisco.util.List;
import org.w3c.dom.Node;

/**
 * A implementation of the "string-length()" function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class StringLength extends FunctionCall {
    
    /**
     * Creates a new StringLength FunctionCall
    **/
    public StringLength() {
        super(Names.STRING_LENGTH_FN);
    } //-- StringLength
    
    /**
     * Evalutes this FunctionCall using the given Node as
     * the context. This method will always return a NumberResult
    **/
    public ExprResult evaluate(Node context, ProcessorState ps) 
        throws InvalidExprException
    {
        List params = getParameterList();
        
        int nparams = params.size();
        if (nparams > 1)
            throw new InvalidExprException(INVALID_NUMBER_PARAMS+this);
            
        String str = null;
        if (nparams == 1) {
            Expr expr = (Expr)params.get(0);
            ExprResult exprResult = expr.evaluate(context, ps);
            str = StringExpr.toStringResult(exprResult).toString();
        }
        else {
            str = XSLObject.getNodeValue(context);
        }
        return new NumberResult((double) str.length());
    } //-- evaluate
    
} //-- StringLength

